// A2DTest.cpp
//
// Applied Data Systems : 4/25/02
//
// This simple application is used to check the A/D input
//   values through the ADSmartIO library, typically found at PA0-PA7.
//   This application reads PA0 - PA7 and outputs their hex values to 
//   the debug port.
//
// 3may02 20-11082 ak
// - DEBUGMSG->RETAILMSG except for library names
// - Add start and end messages
// - Reduce delay from 333ms to 200

#include "stdafx.h"
#define WIN32_LEAN_AND_MEAN
#include <windows.h>

// Declare library for dynamic linking to SMARTIO.DLL
// --------------------------------------------------
HINSTANCE gLibSMARTIO = NULL;

// Declare library for dynamic linking to KEYBDDR.DLL
// --------------------------------------------------
HINSTANCE gLibKEYBDDR = NULL;

typedef UINT (*SIOANALOGCONVERSION)(BYTE channel);
typedef void (*SIOSELECTOPTION)(BYTE Option);
typedef void (*SIOSETSSPTIMEOUT)(UINT Option);
typedef void (*SIOINITDDRA)(BYTE value);
typedef void (*SIOINITDDRB)(BYTE value);
typedef void (*SIOINITDDRC)(BYTE value);
typedef void (*SIOINITDDRD)(BYTE value);
typedef UINT (*SIOREADPORTA)(void);
typedef UINT (*SIOREADPORTB)(void);
typedef UINT (*SIOREADPORTC)(void);
typedef UINT (*SIOREADPORTD)(void);
 

SIOANALOGCONVERSION		SIOAnalogConversion;
SIOSELECTOPTION			SIOSelectOption;
SIOSETSSPTIMEOUT		SIOSetSSPTimeout;
SIOINITDDRA				SIOInitDDRA;

//-------------------------------------------------------------------
//-------------------------------------------------------------------
BOOL LoadSmartIO()
{
	gLibSMARTIO = LoadLibrary((L"SMARTIO.dll"));

	if(gLibSMARTIO == NULL)
	{	
		gLibKEYBDDR = LoadLibrary((L"KEYBDDR.dll"));

		if(gLibKEYBDDR == NULL)
		{	
			RETAILMSG(TRUE,(L"\r\nFailed to load ADSmartIO library.\r\n"));
			return FALSE;
		}
		else
		{	
			DEBUGMSG(TRUE,(L"- Using KEYBDDR.DLL\r\n"));
			gLibSMARTIO = gLibKEYBDDR;
			//GraphicsClientPlus = 1;
		}
	}
	else
	{	
		DEBUGMSG(TRUE,(L"- Using SMARTIO.DLL\r\n"));
		// GraphicsMaster = 1;
	}

	if(gLibSMARTIO!=NULL)
	{	
		SIOAnalogConversion = (SIOANALOGCONVERSION)GetProcAddress(gLibSMARTIO,(_T("SIOAnalogConversion")));
		SIOSelectOption = (SIOSELECTOPTION)GetProcAddress(gLibSMARTIO,(L"SIOSelectOption"));
		SIOSetSSPTimeout = (SIOSETSSPTIMEOUT)GetProcAddress(gLibSMARTIO,(L"SIOSetSSPTimeout"));
		SIOInitDDRA = (SIOINITDDRA)GetProcAddress(gLibSMARTIO,(L"SIOInitDDRA"));
	}

	return TRUE;

}

//-------------------------------------------------------------------
//-------------------------------------------------------------------
int WINAPI WinMain(	HINSTANCE hInstance,
					HINSTANCE hPrevInstance,
					LPTSTR    lpCmdLine,
					int       nCmdShow)
{
	int iterations = 0;

  RETAILMSG(TRUE,(L"\r\nA2Dtest: Reads eight ADSmartIO A/D inputs.  Writes results to debug port.\r\n"));

	if (!LoadSmartIO())
  {
    RETAILMSG(TRUE,(L"Program aborted.\r\n"));
    return(1);
  }

	SIOSelectOption(2);
	SIOInitDDRA(0x00);

	SIOSetSSPTimeout(500);

	while(TRUE)
	{		
    // return to start of line each time
    RETAILMSG(TRUE, (_T("\r  ")));

    // read data
    for(int i = 0 ; i < 8 ; i++)
			RETAILMSG(TRUE, (_T("0x%04X "), SIOAnalogConversion(i)));

		Sleep(250);

  }

  RETAILMSG(TRUE,(L"\r\nA2Dtest: Complete (should never get here).\r\n"));

	return 0;

}

